==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/bypass/BypassListFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.bypass;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class BypassListFluentImpl<A extends BypassListFluent<A>> extends BaseFluent<A> implements BypassListFluent<A>{

    private String apiVersion;
    private List<BypassBuilder> items;
    private String kind;
    private ListMeta metadata;

    public BypassListFluentImpl(){
    }
    public BypassListFluentImpl(BypassList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A addToItems(int index,Bypass item){
            if (this.items == null) {this.items = new ArrayList<BypassBuilder>();}
            BypassBuilder builder = new BypassBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,Bypass item){
            if (this.items == null) {this.items = new ArrayList<BypassBuilder>();}
            BypassBuilder builder = new BypassBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(Bypass... items){
            if (this.items == null) {this.items = new ArrayList<BypassBuilder>();}
            for (Bypass item : items) {BypassBuilder builder = new BypassBuilder(item);_visitables.add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<Bypass> items){
            if (this.items == null) {this.items = new ArrayList<BypassBuilder>();}
            for (Bypass item : items) {BypassBuilder builder = new BypassBuilder(item);_visitables.add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(Bypass... items){
            for (Bypass item : items) {BypassBuilder builder = new BypassBuilder(item);_visitables.remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<Bypass> items){
            for (Bypass item : items) {BypassBuilder builder = new BypassBuilder(item);_visitables.remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Bypass> getItems(){
            return build(items);
    }

    public List<Bypass> buildItems(){
            return build(items);
    }

    public Bypass buildItem(int index){
            return this.items.get(index).build();
    }

    public Bypass buildFirstItem(){
            return this.items.get(0).build();
    }

    public Bypass buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public Bypass buildMatchingItem(Predicate<BypassBuilder> predicate){
            for (BypassBuilder item: items) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withItems(List<Bypass> items){
            if (this.items != null) { _visitables.removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<BypassBuilder>(); for (Bypass item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(Bypass... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (Bypass item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public BypassListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public BypassListFluent.ItemsNested<A> addNewItemLike(Bypass item){
            return new ItemsNestedImpl(-1, item);
    }

    public BypassListFluent.ItemsNested<A> setNewItemLike(int index,Bypass item){
            return new ItemsNestedImpl(index, item);
    }

    public BypassListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public BypassListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public BypassListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public BypassListFluent.ItemsNested<A> editMatchingItem(Predicate<BypassBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            BypassListFluentImpl that = (BypassListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends BypassFluentImpl<BypassListFluent.ItemsNested<N>> implements BypassListFluent.ItemsNested<N>,Nested<N>{

            private final BypassBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,Bypass item){
                    this.index = index;
                    this.builder = new BypassBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new BypassBuilder(this);
            }
    
    public N and(){
            return (N) BypassListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/bypass/BypassListFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.bypass;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class BypassListFluentImpl<A extends BypassListFluent<A>> extends BaseFluent<A> implements BypassListFluent<A>{

    private String apiVersion;
    private List<BypassBuilder> items;
    private String kind;
    private ListMeta metadata;

    public BypassListFluentImpl(){
    }
    public BypassListFluentImpl(BypassList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,Bypass item){
            if (this.items == null) {this.items = new ArrayList<BypassBuilder>();}
            BypassBuilder builder = new BypassBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,Bypass item){
            if (this.items == null) {this.items = new ArrayList<BypassBuilder>();}
            BypassBuilder builder = new BypassBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(Bypass... items){
            if (this.items == null) {this.items = new ArrayList<BypassBuilder>();}
            for (Bypass item : items) {BypassBuilder builder = new BypassBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<Bypass> items){
            if (this.items == null) {this.items = new ArrayList<BypassBuilder>();}
            for (Bypass item : items) {BypassBuilder builder = new BypassBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(Bypass... items){
            for (Bypass item : items) {BypassBuilder builder = new BypassBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<Bypass> items){
            for (Bypass item : items) {BypassBuilder builder = new BypassBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<BypassBuilder> predicate){
            if (items == null) return (A) this;
            final Iterator<BypassBuilder> each = items.iterator();
            final List visitables = _visitables.get("items");
            while (each.hasNext()) {
              BypassBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Bypass> getItems(){
            return build(items);
    }

    public List<Bypass> buildItems(){
            return build(items);
    }

    public Bypass buildItem(int index){
            return this.items.get(index).build();
    }

    public Bypass buildFirstItem(){
            return this.items.get(0).build();
    }

    public Bypass buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public Bypass buildMatchingItem(Predicate<BypassBuilder> predicate){
            for (BypassBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<BypassBuilder> predicate){
            for (BypassBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(List<Bypass> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<BypassBuilder>(); for (Bypass item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(Bypass... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (Bypass item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public BypassListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public BypassListFluent.ItemsNested<A> addNewItemLike(Bypass item){
            return new ItemsNestedImpl(-1, item);
    }

    public BypassListFluent.ItemsNested<A> setNewItemLike(int index,Bypass item){
            return new ItemsNestedImpl(index, item);
    }

    public BypassListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public BypassListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public BypassListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public BypassListFluent.ItemsNested<A> editMatchingItem(Predicate<BypassBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            BypassListFluentImpl that = (BypassListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends BypassFluentImpl<BypassListFluent.ItemsNested<N>> implements BypassListFluent.ItemsNested<N>,Nested<N>{

            private final BypassBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,Bypass item){
                    this.index = index;
                    this.builder = new BypassBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new BypassBuilder(this);
            }
    
    public N and(){
            return (N) BypassListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}
